@@ -1,24 +1,29 @@
 import unittest
 import Tkinter
 import ttk
+from test.test_support import requires, run_unittest
 
 import support
 
+requires('gui')
+
 class StyleTest(unittest.TestCase):
 
     def setUp(self):
-        root = Tkinter.Tk()
-        self.style = ttk.Style(root)
+        self.root = support.get_tk_root()
+        self.style = ttk.Style(self.root)
 
     def tearDown(self):
-        self.style.master.destroy()
+        # As tests have shown, these tests are likely to deliver
+        # <<ThemeChanged>> events after the root is destroyed, so
+        # lets let them happen now.
+        self.root.update_idletasks()
+        self.root.destroy()
 
 
     def test_configure(self):
         style = self.style
         style.configure('TButton', background='yellow')
-        self.failUnlessEqual(style.configure('TButton', 'background'),
-            style.configure('TButton', '-background'))
         self.failUnlessEqual(style.configure('TButton', 'background'),
             'yellow')
         self.failUnless(isinstance(style.configure('TButton'), dict))
@@ -27,8 +32,6 @@ class StyleTest(unittest.TestCase):
     def test_map(self):
         style = self.style
         style.map('TButton', background=[('active', 'background', 'blue')])
-        self.failUnlessEqual(style.map('TButton', 'background'),
-            style.map('TButton', '-background'))
         self.failUnlessEqual(style.map('TButton', 'background'),
             [('active', 'background', 'blue')])
         self.failUnless(isinstance(style.map('TButton'), dict))
@@ -39,8 +42,6 @@ class StyleTest(unittest.TestCase):
         style.configure('TButton', background='yellow')
         style.map('TButton', background=[('active', 'background', 'blue')])
 
-        self.failUnlessEqual(style.lookup('TButton', 'background'),
-            style.lookup('TButton', '-background'))
         self.failUnlessEqual(style.lookup('TButton', 'background'), 'yellow')
         self.failUnlessEqual(style.lookup('TButton', 'background',
             ['active', 'background']), 'blue')
@@ -92,8 +93,7 @@ class StyleTest(unittest.TestCase):
         self.style.theme_use(curr_theme)
 
 
-def test_main():
-    support.run(StyleTest)
+tests = [StyleTest]
 
 if __name__ == "__main__":
-    test_main()
+    run_unittest(*tests)
