@@ -12,7 +12,7 @@ maintaining the widget state and invoking callbacks, all aspects
 of the widgets appearance lies at Themes.
 """
 
-__version__ = "0.2.6"
+__version__ = "0.3"
 
 __author__ = "Guilherme Polo <ggpolo@gmail.com>"
 
@@ -51,8 +51,12 @@ def _loadttk(loadtk):
 
     return _wrapper
 
+# Store the original Tkinter.Tk._loadtk before replacing it just in case
+# someone wants to restore it.
+__loadtk__ = Tkinter.Tk._loadtk
 Tkinter.Tk._loadtk = _loadttk(Tkinter.Tk._loadtk)
 
+
 def _format_optdict(optdict, script=False, ignore=None):
     """Formats optdict to a tuple to pass it to tk.call.
     
@@ -84,6 +88,7 @@ def _format_optdict(optdict, script=False, ignore=None):
 
         opts.append(("-%s" % opt, value))
 
+    # Remember: _flatten skips over None
     return _flatten(opts)
 
 def _format_mapdict(mapdict, script=False):
@@ -359,10 +364,12 @@ class Style(object):
     _name = "ttk::style"
 
     def __init__(self, master=None):
-        if not master:
-            if not Tkinter._default_root:
-                Tkinter._default_root = Tkinter.Tk()
-            master = Tkinter._default_root
+        if master is None:
+            if Tkinter._support_default_root:
+                master = Tkinter._default_root or Tkinter.Tk()
+            else:
+                raise RuntimeError("No master specified and Tkinter is "
+                    "configured to not support default master")
 
         self.master = master
         self.tk = self.master.tk
@@ -374,13 +381,9 @@ class Style(object):
 
         Each key in kw is an option and each value is either a string or
         a sequence identifying the value for that option."""
-        if query_opt:
-            query_opt = ('' if query_opt.startswith('-') else '-') + query_opt
-            return self.tk.call(self._name, "configure", style, query_opt)
-
-        return _dict_from_tcltuple(
-            self.tk.call(
-                self._name, "configure", style, *(_format_optdict(kw))))
+        if query_opt is not None:
+            kw[query_opt] = None
+        return _val_or_dict(kw, self.tk.call, self._name, "configure", style)
 
 
     def map(self, style, query_opt=None, **kw):
@@ -391,10 +394,9 @@ class Style(object):
         tuple (usually) containing statespecs grouped in tuples, or list,
         or something else of your preference. A statespec is compound of
         one or more states and then a value."""
-        if query_opt:
-            query_opt = ('' if query_opt.startswith('-') else '-') + query_opt
+        if query_opt is not None:
             return _list_from_statespec(
-                self.tk.call(self._name, "map", style, query_opt))
+                self.tk.call(self._name, "map", style, '-%s' % query_opt))
 
         return _dict_from_tcltuple(
             self.tk.call(self._name, "map", style, *(_format_mapdict(kw))))
@@ -407,9 +409,9 @@ class Style(object):
         or more states. If the default argument is set, it is used as
         a fallback value in case no specification for option is found."""
         state = ' '.join(state) if state else ''
-        option = ('-' if not option.startswith('-') else '') + option
 
-        return self.tk.call(self._name, "lookup", style, option, state, default)
+        return self.tk.call(self._name, "lookup", style, '-%s' % option,
+            state, default)
 
 
     def layout(self, style, layoutspec=None):
@@ -898,12 +900,14 @@ class Notebook(Widget):
         return self.tk.call(self._w, "select", tab_id)
 
 
-    def tab(self, tab_id, **kw):
-        """Query or modify the options of the specific tab.
+    def tab(self, tab_id, option=None, **kw):
+        """Query or modify the options of the specific tab_id.
 
-        If no option is specified, returns a dictionary of the tab option
-        values. If one option is specified, returns the value of that
-        option. Otherwise, sets the options to the corresponding values."""
+        If kw is not given, returns a dict of the tab option values. If option
+        is specified, returns the value of that option. Otherwise, sets the
+        options to the corresponding values."""
+        if option is not None:
+            kw[option] = None
         return _val_or_dict(kw, self.tk.call, self._w, "tab", tab_id)
 
 
@@ -972,13 +976,15 @@ class Panedwindow(Widget, Tkinter.PanedWindow):
         self.tk.call(self._w, "insert", pos, child, *(_format_optdict(kw)))
 
 
-    def pane(self, pane, **kw):
+    def pane(self, pane, option=None, **kw):
         """Query or modify the options of the specified pane.
 
-        pane is either an integer index or the name of a managed
-        subwindow. If no options are specified, returns a dict of the
-        pane option values, if an option is specified without a value,
-        returns the value of that option. Otherwise, the options are set."""
+        pane is either an integer index or the name of a managed subwindow.
+        If kw is not given, returns a dict of the pane option values. If
+        option is specified then the value for that option is returned.
+        Otherwise, sets the options to the correspoding values."""
+        if option is not None:
+            kw[option] = None
         return _val_or_dict(kw, self.tk.call, self._w, "pane", pane)
 
 
@@ -1209,17 +1215,18 @@ class Treeview(Widget):
         self.tk.call(self._w, "children", item, newchildren)
 
 
-    def column(self, column, **kw):
+    def column(self, column, option=None, **kw):
         """Query or modify the options for the specified column.
 
-        If no options are specified, returns a dictionary of option/value
-        pairs. If an option is specified with value None, returns the
-        value of that option. Otherwise, the options are updated with the
-        specified values."""
+        If kw is not given, returns a dict of the column option values. If
+        option is specified then the value for that option is returned.
+        Otherwise, sets the options to the corresponding values."""
+        if option is not None:
+            kw[option] = None
         return _val_or_dict(kw, self.tk.call, self._w, "column", column)
 
 
-    def delete(self, items):
+    def delete(self, *items):
         """Delete all specified items and all their descendants. The root
         item may not be deleted."""
         self.tk.call(self._w, "delete", items)
@@ -1246,9 +1253,13 @@ class Treeview(Widget):
         return self.tk.call(self._w, "focus", item)
 
 
-    def heading(self, column, **kw):
+    def heading(self, column, option=None, **kw):
         """Query or modify the heading options for the specified column.
 
+        If kw is not given, returns a dict of the heading option values. If
+        option is specified then the value for that option is returned.
+        Otherwise, sets the options to the corresponding values.
+
         Valid options/values are:
             text: text
                 The text to display in the column heading
@@ -1268,6 +1279,9 @@ class Treeview(Widget):
             # callback not registered yet, do it now
             kw['command'] = self.master.register(cmd, self._substitute)
 
+        if option is not None:
+            kw[option] = None
+
         return _val_or_dict(kw, self.tk.call, self._w, 'heading', column)
 
 
@@ -1338,13 +1352,15 @@ class Treeview(Widget):
         return res
 
 
-    def item(self, item, **kw):
+    def item(self, item, option=None, **kw):
         """Query or modify the options for the specified item.
 
-        If no options are specified, returns a dictionary of option/value
-        pairs. If a single option is specified with value None, returns
-        the value of that option. Otherwise, the item's options are
-        updated with the specified values."""
+        If no options are given, a dict with options/values for the item
+        is returned. If option is specified then the value for that option
+        is returned. Otherwise, sets the options to the corresponding
+        values as given by kw."""
+        if option is not None:
+            kw[option] = None
         return _val_or_dict(kw, self.tk.call, self._w, "item", item)
 
 
@@ -1431,15 +1447,15 @@ class Treeview(Widget):
         self._bind((self._w, "tag", "bind", tagname), sequence, callback, add=0)
 
 
-    def tag_configure(self, tagname, **kw):
+    def tag_configure(self, tagname, option=None, **kw):
         """Query or modify the options for the specified tagname.
 
-        If one or more option/value pairs are specified, sets the value
-        of those options for the specified tag. If a single option
-        is specified with value None, returns the value of that option
-        (or the empty string if the option has not been specified for
-        tagname). With no additional arguments, returns a dictionary of
-        the option settings for tagname."""
+        If kw is not given, returns a dict of the option settings for tagname.
+        If option is specified, returns the value for that option for the
+        specified tagname. Otherwise, sets the options to the corresponding
+        values for the given tagname."""
+        if option is not None:
+            kw[option] = None
         return _val_or_dict(kw, self.tk.call, self._w, "tag", "configure",
             tagname)
 
@@ -1509,9 +1525,14 @@ class LabeledScale(Frame, object):
 
     def destroy(self):
         """Destroy this widget and possibly its associated variable."""
-        self._variable.trace_vdelete('w', self.__tracecb)
-        del self._variable
-        Frame.destroy(self)
+        try:
+            self._variable.trace_vdelete('w', self.__tracecb)
+        except AttributeError:
+            # widget has been destroyed already
+            pass
+        else:
+            del self._variable
+            Frame.destroy(self)
 
 
     def _adjust(self, *args):
